Crate kopium

Crate kopium 

Structs

Config
Container
Output container found by analyzer
Derive
A trait to derive, as well as the object for which to derive it.
Member
Output member belonging to an Container
Output
All found containers
TypeGenerator

Enums

MapType
Type used for additionalProperties maps
SchemaMode
Supported values for kube’s [schema] attribute.

Functions

all_crd_versions
analyze
Scan a schema for structs and members, and recurse to find all structs
find_crd_version
format_docstr
format_selectable
has_status_resource