Structs
- Config
- Container
- Output container found by analyzer
- Derive
- A trait to derive, as well as the object for which to derive it.
- Member
- Output member belonging to an Container
- Output
- All found containers
- Type
Generator
Enums
- MapType
- Type used for additionalProperties maps
- Schema
Mode - Supported values for
kube’s [schema] attribute.
Functions
- all_
crd_ versions - analyze
- Scan a schema for structs and members, and recurse to find all structs
- find_
crd_ version - format_
docstr - format_
selectable - has_
status_ resource